pub struct CrystalBuilder<LatticeState, AtomsState> { /* private fields */ }Expand description
use builder pattern so the validation is runtime
To make it a compile time check, I can use the proc macro (build/build_unchcek API).
Example
use ccmat::*;
let lattice = lattice_angstrom![
a = (1.0, 0.0, 0.0),
b = (0.0, 1.0, 0.0),
c = (0.0, 0.0, 1.0),
];
let atoms = vec![];
let crystal = CrystalBuilder::new()
.with_lattice(lattice)
.with_atoms(&atoms)
.build()
.unwrap();Implementations
Sourceimpl<A> CrystalBuilder<LatticeNotSet, A>
impl<A> CrystalBuilder<LatticeNotSet, A>
pub fn with_lattice(self, lattice: Lattice) -> CrystalBuilder<LatticeSet, A>
Sourceimpl<L> CrystalBuilder<L, AtomsNotSet>
impl<L> CrystalBuilder<L, AtomsNotSet>
pub fn with_atoms(self, atoms: &[Atom]) -> CrystalBuilder<L, AtomsSet>
Sourceimpl CrystalBuilder<LatticeSet, AtomsSet>
impl CrystalBuilder<LatticeSet, AtomsSet>
Sourcepub fn build(self) -> Result<Crystal, CrystalValidateError>
pub fn build(self) -> Result<Crystal, CrystalValidateError>
build and validate the it is a valid crystal. At the moment only validate the size(positions) == size(numbers)